@@ -10,10 +10,9 @@
 """
 from .plugin import HttpProxyBasePlugin
 from .server import HttpProxyPlugin
-from .auth import AuthPlugin
+
 
 __all__ = [
     'HttpProxyBasePlugin',
     'HttpProxyPlugin',
-    'AuthPlugin',
 ]
